@@ -9,7 +9,24 @@ use std::fs::remove_file;
 use std::path::{Path, PathBuf};
 
 use cfg_if::cfg_if;
-use log::*;
+
+cfg_if! {
+    if #[cfg(feature = "logging")] {
+        pub use log;
+    } else {
+        #[allow(unused_macros)]
+        mod log {
+            macro_rules! trace (($($tt:tt)*) => {{}});
+            macro_rules! debug (($($tt:tt)*) => {{}});
+            macro_rules! info (($($tt:tt)*) => {{}});
+            macro_rules! warn (($($tt:tt)*) => {{}});
+            macro_rules! error (($($tt:tt)*) => {{}});
+            pub(crate) use {debug, trace};
+        }
+    }
+}
+
+use crate::log::*;
 
 mod error;
 pub use error::*;
@@ -27,7 +44,7 @@ cfg_if! {
     }
 }
 
-#[derive(Clone)]
+#[derive(Clone, Default)]
 /// Struct used to configure different parameters before creating a shared memory mapping
 pub struct ShmemConf {
     owner: bool,
@@ -47,17 +64,7 @@ impl Drop for ShmemConf {
         }
     }
 }
-impl Default for ShmemConf {
-    fn default() -> Self {
-        Self {
-            owner: false,
-            os_id: None,
-            overwrite_flink: false,
-            flink_path: None,
-            size: 0,
-        }
-    }
-}
+
 impl ShmemConf {
     /// Create a new default shmem config
     pub fn new() -> Self {
@@ -98,6 +105,12 @@ impl ShmemConf {
             return Err(ShmemError::MapSizeZero);
         }
 
+        if let Some(ref flink_path) = self.flink_path {
+            if !self.overwrite_flink && flink_path.is_file() {
+                return Err(ShmemError::LinkExists);
+            }
+        }
+
         // Create the mapping
         let mapping = match self.os_id {
             None => {
@@ -246,7 +259,7 @@ impl Shmem {
     }
     /// Returns a raw pointer to the mapping
     pub fn as_ptr(&self) -> *mut u8 {
-        self.mapping.map_ptr
+        self.mapping.as_mut_ptr()
     }
     /// Returns mapping as a byte slice
     /// # Safety
